"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateReader = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const _config_1 = require("./_config");
const promises_1 = require("fs/promises");
const ErrorList_1 = require("./ErrorList");
class TemplateReader {
    constructor(templateName, templatePath) {
        this.templateName = templateName;
        this.templatePath = templatePath;
        const matchResult = templateName.match(/([^\/]*)\/*$/);
        this.templateDirName = matchResult[1];
    }
    static getTemplateConfigFile(templatePath) {
        const configFilePath = `${templatePath}/${_config_1.nameConfigFile}`;
        try {
            if (!fs_1.default.existsSync(configFilePath))
                return new Error(ErrorList_1.ErrorList.CONFIG_FIlE_MISS(templatePath));
            const fileBuffer = fs_1.default.readFileSync(path_1.default.resolve(configFilePath));
            return JSON.parse(fileBuffer.toString());
        }
        catch (err) {
            return new Error(ErrorList_1.ErrorList.UNEXPECTED_ERROR(err));
        }
    }
    static checkConfigFileProperties(configFile) {
        const errors = [];
        if (!configFile.template)
            errors.push(ErrorList_1.ErrorList.CONFIG_FILE_INVALID('template', "string"));
        else if (!configFile.componentWorkDir)
            errors.push(ErrorList_1.ErrorList.CONFIG_FILE_INVALID('componentWorkDir', "string || Object "));
        else if (typeof configFile.componentWorkDir === "object") {
            if (!configFile.componentWorkDir.extensionWorkDir)
                errors.push(ErrorList_1.ErrorList.CONFIG_FILE_INVALID('componentWorkDir.extensionWorkDir', "string"));
            else if (!configFile.componentWorkDir.extensionWorkDir)
                errors.push(ErrorList_1.ErrorList.CONFIG_FILE_INVALID('componentWorkDir.extensionWorkDir', "string"));
        }
        if (errors.length)
            return new Error(errors.join("\n"));
    }
    getTemplateFiles() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const result = yield (0, promises_1.readdir)(this.templatePath, { withFileTypes: true });
                return result
                    .filter(file => file.isFile() && file.name !== _config_1.nameConfigFile)
                    .map(file => ({
                    fileName: file.name,
                    filePath: `${this.templatePath}/${file.name}`,
                }));
            }
            catch (err) {
                return new Error(ErrorList_1.ErrorList.UNEXPECTED_ERROR(err));
            }
        });
    }
}
exports.TemplateReader = TemplateReader;
//# sourceMappingURL=TemplateReader.js.map