"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TemplateRepo = void 0;
const TemplateReader_1 = require("./TemplateReader");
const ErrorList_1 = require("./ErrorList");
const conf_1 = __importDefault(require("conf"));
const Initialize_1 = require("./commands/Initialize");
class TEMPLATE_NOT_FOUND extends Error {
    constructor(message) {
        super(message);
        this.name = "TEMPLATE_NOT_FOUND_ERROR";
    }
}
class TemplateRepository {
    constructor(Store) {
        this.Store = Store;
    }
    clear() {
        this.Store.clear();
    }
    saveTemplate(templateName, templatePath) {
        this.Store.set(templateName, templatePath);
    }
    getMetadata(templateName) {
        return __awaiter(this, void 0, void 0, function* () {
            let metadataResult = this._getTemplateMetadata(templateName);
            if (metadataResult instanceof TEMPLATE_NOT_FOUND) {
                const reloadResult = yield Initialize_1.initializer.reload();
                if (reloadResult instanceof Error)
                    return reloadResult;
                metadataResult = this._getTemplateMetadata(templateName);
                if (metadataResult instanceof Error)
                    return metadataResult;
                const consistencyResult = this.checkTemplateConsistency(templateName, metadataResult.configFile);
                if (consistencyResult instanceof Error)
                    return consistencyResult;
                return metadataResult;
            }
            else if (!(metadataResult instanceof Error)) {
                const consistencyResult = yield this.checkTemplateConsistency(templateName, metadataResult.configFile);
                if (consistencyResult)
                    return metadataResult;
                const reloadResult = yield Initialize_1.initializer.reload();
                if (reloadResult instanceof Error)
                    return reloadResult;
                metadataResult = this._getTemplateMetadata(templateName);
                if (metadataResult instanceof Error)
                    return metadataResult;
                return metadataResult;
            }
            else
                return metadataResult;
        });
    }
    checkTemplateConsistency(cacheTempName, configFile) {
        const checkingResult = TemplateReader_1.TemplateReader.checkConfigFileProperties(configFile);
        if (checkingResult instanceof Error)
            return checkingResult;
        if (configFile.template === cacheTempName)
            return true;
        return new Error(ErrorList_1.ErrorList.TEMPLATE_NOT_EXIST(cacheTempName));
    }
    _getTemplateMetadata(templateName) {
        const path = this.Store.get(templateName);
        if (!path)
            return new TEMPLATE_NOT_FOUND(ErrorList_1.ErrorList.TEMPLATE_NOT_EXIST(templateName));
        const configFileResult = TemplateReader_1.TemplateReader.getTemplateConfigFile(path);
        if (configFileResult instanceof Error)
            return configFileResult;
        return { path, configFile: configFileResult };
    }
}
exports.TemplateRepo = new TemplateRepository(new conf_1.default());
//# sourceMappingURL=TemplateRepository.js.map